@@ -2,10 +2,12 @@
 Base45 Data Encoding as described in draft-faltstrom-base45-02
 """
 
+from typing import Union
+
 BASE45_CHARSET = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ $%*+-./:"
 
 
-def b45encode(buf: bytes) -> str:
+def b45encode(buf: bytes) -> bytes:
     """Convert bytes to base45-encoded string"""
     res = ""
     buflen = len(buf)
@@ -19,14 +21,17 @@ def b45encode(buf: bytes) -> str:
             x = buf[i]
             d, c = divmod(x, 45)
             res += BASE45_CHARSET[c] + BASE45_CHARSET[d]
-    return res
+    return res.encode()
 
 
-def b45decode(s: str) -> bytes:
+def b45decode(s: Union[bytes, str]) -> bytes:
     """Decode base45-encoded string to bytes"""
     res = []
     try:
-        buf = [BASE45_CHARSET.index(c) for c in s]
+        if isinstance(s, str):
+            buf = [BASE45_CHARSET.index(c) for c in s]
+        else:
+            buf = [BASE45_CHARSET.index(c) for c in s.decode()]
         buflen = len(buf)
         for i in range(0, buflen, 3):
             x = buf[i] + buf[i + 1] * 45
@@ -36,5 +41,5 @@ def b45decode(s: str) -> bytes:
             else:
                 res.append(x)
         return bytes(res)
-    except (ValueError, IndexError):
+    except (ValueError, IndexError, AttributeError):
         raise ValueError("Invalid base45 string")
